==> audiowidgets-swing_2.12-1.10.2-sources.jar: de/sciss/audiowidgets/Axis.scala <==
/*
 *  Axis.scala
 *  (AudioWidgets)
 *
 *  Copyright (c) 2011-2016 Hanns Holger Rutz. All rights reserved.
 *
 *	This software is published under the GNU Lesser General Public License v2.1+
 *
 *
 *	For further information, please contact Hanns Holger Rutz at
 *	contact@sciss.de
 */

package de.sciss.audiowidgets

import j.{Axis => JAxis}
import scala.swing.{Font, Orientation, Component}

object Axis {
  def DefaultFont: Font = JAxis.DefaultFont
}
class Axis(orientation0: Orientation.Value = Orientation.Horizontal) extends Component with AxisLike {
  override lazy val peer: JAxis = new JAxis(orientation0.id) with SuperMixin

  def orientation        : Orientation.Value        = Orientation(peer.orientation)
  def orientation_=(value: Orientation.Value): Unit = peer.orientation = value.id

  def fixedBounds        : Boolean                  = peer.fixedBounds
  def fixedBounds_=(b    : Boolean          ): Unit = peer.fixedBounds = b

  def format             : AxisFormat               = peer.format
  def format_=     (f    : AxisFormat       ): Unit = peer.format = f

  def inverted           : Boolean                  = peer.inverted
  def inverted_=   (b    : Boolean          ): Unit = peer.inverted = b

  def maximum            : Double                   = peer.maximum
  def maximum_=    (value: Double           ): Unit = peer.maximum = value

  def minimum            : Double                   = peer.minimum
  def minimum_=    (value: Double           ): Unit = peer.minimum = value
}

==> audiowidgets-swing_2.13-2.4.3-sources.jar: de/sciss/audiowidgets/Axis.scala <==
/*
 *  Axis.scala
 *  (AudioWidgets)
 *
 *  Copyright (c) 2011-2020 Hanns Holger Rutz. All rights reserved.
 *
 *	This software is published under the GNU Lesser General Public License v2.1+
 *
 *
 *	For further information, please contact Hanns Holger Rutz at
 *	contact@sciss.de
 */

package de.sciss.audiowidgets

import de.sciss.audiowidgets.j.{Axis => JAxis}

import scala.swing.{Component, Font, Orientation}

object Axis {
  def DefaultFont: Font = JAxis.DefaultFont
}
class Axis(orientation0: Orientation.Value = Orientation.Horizontal) extends Component with AxisLike {
  override lazy val peer: JAxis = new JAxis(orientation0.id) with SuperMixin

  def orientation        : Orientation.Value        = Orientation(peer.orientation)
  def orientation_=(value: Orientation.Value): Unit = peer.orientation = value.id

  def fixedBounds        : Boolean                  = peer.fixedBounds
  def fixedBounds_=(b    : Boolean          ): Unit = peer.fixedBounds = b

  def format             : AxisFormat               = peer.format
  def format_=     (f    : AxisFormat       ): Unit = peer.format = f

  def inverted           : Boolean                  = peer.inverted
  def inverted_=   (b    : Boolean          ): Unit = peer.inverted = b

  def logarithmic        : Boolean                  = peer.logarithmic
  def logarithmic_=(b    : Boolean          ): Unit = peer.logarithmic = b

  def maximum            : Double                   = peer.maximum
  def maximum_=    (value: Double           ): Unit = peer.maximum = value

  def minimum            : Double                   = peer.minimum
  def minimum_=    (value: Double           ): Unit = peer.minimum = value

  /** Translates a screen location (between zero and the length of the axis in pixels) to
    * a model value on the axis.
    */
  def screenToModel(pos: Double): Double = peer.screenToModel(pos)

  /** Creates a formatted string from a given model value,
    * corresponding with the current axis label formatting.
    */
  def formatModelValue(v: Double): String = peer.formatModelValue(v)
}
